@@ -90,7 +90,7 @@ format_error({bad_module, Mod}, Ctx)
   when Ctx == [listen, module];
        Ctx == [listen, request_handlers] ->
     Mods = ejabberd_config:beams(all),
-    format("~s: unknown ~s: ~s. Did you mean ~s?",
+    format("~ts: unknown ~ts: ~ts. Did you mean ~ts?",
 	   [yconf:format_ctx(Ctx),
 	    format_module_type(Ctx),
 	    format_module(Mod),
@@ -105,7 +105,7 @@ format_error({bad_module, Mod}, Ctx)
 			 _ -> false
 		     end
 	     end, ejabberd_config:beams(all)),
-    format("~s: unknown ~s: ~s. Did you mean ~s?",
+    format("~ts: unknown ~ts: ~ts. Did you mean ~ts?",
 	   [yconf:format_ctx(Ctx),
 	    format_module_type(Ctx),
 	    format_module(Mod),
@@ -118,30 +118,30 @@ format_error({bad_export, {F, A}, Mod}, Ctx)
     Slogan = yconf:format_ctx(Ctx),
     case lists:member(Mod, ejabberd_config:beams(local)) of
 	true ->
-	    format("~s: '~s' is not a ~s",
+	    format("~ts: '~ts' is not a ~ts",
 		   [Slogan, format_module(Mod), Type]);
 	false ->
 	    case lists:member(Mod, ejabberd_config:beams(external)) of
 		true ->
-		    format("~s: third-party ~s '~s' doesn't export "
-			   "function ~s/~B. If it's really a ~s, "
+		    format("~ts: third-party ~ts '~ts' doesn't export "
+			   "function ~ts/~B. If it's really a ~ts, "
 			   "consider to upgrade it",
 			   [Slogan, Type, format_module(Mod),F, A, Type]);
 		false ->
-		    format("~s: '~s' doesn't match any known ~s",
+		    format("~ts: '~ts' doesn't match any known ~ts",
 			   [Slogan, format_module(Mod), Type])
 	    end
     end;
 format_error({unknown_option, [], _} = Why, Ctx) ->
-    format("~s. There are no available options",
+    format("~ts. There are no available options",
 	   [yconf:format_error(Why, Ctx)]);
 format_error({unknown_option, Known, Opt} = Why, Ctx) ->
-    format("~s. Did you mean ~s? ~s",
+    format("~ts. Did you mean ~ts? ~ts",
 	   [yconf:format_error(Why, Ctx),
 	    misc:best_match(Opt, Known),
 	    format_known("Available options", Known)]);
 format_error({bad_enum, Known, Bad} = Why, Ctx) ->
-    format("~s. Did you mean ~s? ~s",
+    format("~ts. Did you mean ~ts? ~ts",
 	   [yconf:format_error(Why, Ctx),
 	    misc:best_match(Bad, Known),
 	    format_known("Possible values", Known)]);
@@ -152,43 +152,43 @@ format_error(Reason, Ctx) ->
     yconf:format_ctx(Ctx) ++ ": " ++ [string:to_lower(H)|T].
 
 format_error({bad_db_type, _, Atom}) ->
-    format("unsupported database: ~s", [Atom]);
+    format("unsupported database: ~ts", [Atom]);
 format_error({bad_lang, Lang}) ->
-    format("Invalid language tag: ~s", [Lang]);
+    format("Invalid language tag: ~ts", [Lang]);
 format_error({bad_pem, Why, Path}) ->
-    format("Failed to read PEM file '~s': ~s",
+    format("Failed to read PEM file '~ts': ~ts",
 	   [Path, pkix:format_error(Why)]);
 format_error({bad_cert, Why, Path}) ->
     format_error({bad_pem, Why, Path});
 format_error({bad_jwt_key, Path}) ->
-    format("No valid JWT key found in file: ~s", [Path]);
+    format("No valid JWT key found in file: ~ts", [Path]);
 format_error({bad_jid, Bad}) ->
-    format("Invalid XMPP address: ~s", [Bad]);
+    format("Invalid XMPP address: ~ts", [Bad]);
 format_error({bad_user, Bad}) ->
-    format("Invalid user part: ~s", [Bad]);
+    format("Invalid user part: ~ts", [Bad]);
 format_error({bad_domain, Bad}) ->
-    format("Invalid domain: ~s", [Bad]);
+    format("Invalid domain: ~ts", [Bad]);
 format_error({bad_resource, Bad}) ->
-    format("Invalid resource part: ~s", [Bad]);
+    format("Invalid resource part: ~ts", [Bad]);
 format_error({bad_ldap_filter, Bad}) ->
-    format("Invalid LDAP filter: ~s", [Bad]);
+    format("Invalid LDAP filter: ~ts", [Bad]);
 format_error({bad_sip_uri, Bad}) ->
-    format("Invalid SIP URI: ~s", [Bad]);
+    format("Invalid SIP URI: ~ts", [Bad]);
 format_error({route_conflict, R}) ->
-    format("Failed to reuse route '~s' because it's "
+    format("Failed to reuse route '~ts' because it's "
 	   "already registered on a virtual host",
 	   [R]);
 format_error({listener_dup, AddrPort}) ->
-    format("Overlapping listeners found at ~s",
+    format("Overlapping listeners found at ~ts",
 	   [format_addr_port(AddrPort)]);
 format_error({listener_conflict, AddrPort1, AddrPort2}) ->
-    format("Overlapping listeners found at ~s and ~s",
+    format("Overlapping listeners found at ~ts and ~ts",
 	   [format_addr_port(AddrPort1),
 	    format_addr_port(AddrPort2)]);
 format_error({invalid_syntax, Reason}) ->
-    format("~s", [Reason]);
+    format("~ts", [Reason]);
 format_error({missing_module_dep, Mod, DepMod}) ->
-    format("module ~s depends on module ~s, "
+    format("module ~ts depends on module ~ts, "
 	   "which is not found in the config",
 	   [Mod, DepMod]);
 format_error(eimp_error) ->
@@ -674,7 +674,7 @@ vcard_sound() ->
        {binval, undefined, base64()},
        {extval, undefined, binary()}]).
 
--spec vcard_key() -> yconv:validator().
+-spec vcard_key() -> yconf:validator().
 vcard_key() ->
     vcard_validator(
       vcard_key, undefined,
