@@ -44,7 +44,7 @@
 %% API
 -export([get_presence/1, set_presence/2, resend_presence/1, resend_presence/2,
 	 open_session/1, call/3, cast/2, send/2, close/1, close/2, stop/1,
-	 reply/2, copy_state/2, set_timeout/2, route/2,
+	 reply/2, copy_state/2, set_timeout/2, route/2, format_reason/2,
 	 host_up/1, host_down/1, send_ws_ping/1, bounce_message_queue/2]).
 
 -include("xmpp.hrl").
@@ -268,7 +268,7 @@ reject_unauthenticated_packet(State, _Pkt) ->
 process_auth_result(#{sasl_mech := Mech, auth_module := AuthModule,
 		      socket := Socket, ip := IP, lserver := LServer} = State,
 		    true, User) ->
-    ?INFO_MSG("(~s) Accepted c2s ~s authentication for ~s@~s by ~s backend from ~s",
+    ?INFO_MSG("(~ts) Accepted c2s ~ts authentication for ~ts@~ts by ~ts backend from ~ts",
               [xmpp_socket:pp(Socket), Mech, User, LServer,
                ejabberd_auth:backend_type(AuthModule),
                ejabberd_config:may_hide_data(misc:ip_to_list(IP))]),
@@ -276,7 +276,7 @@ process_auth_result(#{sasl_mech := Mech, auth_module := AuthModule,
 process_auth_result(#{sasl_mech := Mech,
 		      socket := Socket, ip := IP, lserver := LServer} = State,
 		    {false, Reason}, User) ->
-    ?WARNING_MSG("(~s) Failed c2s ~s authentication ~sfrom ~s: ~s",
+    ?WARNING_MSG("(~ts) Failed c2s ~ts authentication ~tsfrom ~ts: ~ts",
                  [xmpp_socket:pp(Socket), Mech,
                   if User /= <<"">> -> ["for ", User, "@", LServer, " "];
                      true -> ""
@@ -291,7 +291,7 @@ process_terminated(#{sid := SID, socket := Socket,
 		     jid := JID, user := U, server := S, resource := R} = State,
 		   Reason) ->
     Status = format_reason(State, Reason),
-    ?INFO_MSG("(~s) Closing c2s session for ~s: ~s",
+    ?INFO_MSG("(~ts) Closing c2s session for ~ts: ~ts",
 	      [xmpp_socket:pp(Socket), jid:encode(JID), Status]),
     State1 = case maps:is_key(pres_last, State) of
 		 true ->
@@ -309,7 +309,7 @@ process_terminated(#{sid := SID, socket := Socket,
     State1;
 process_terminated(#{socket := Socket,
 		     stop_reason := {tls, _}} = State, Reason) ->
-    ?WARNING_MSG("(~s) Failed to secure c2s connection: ~s",
+    ?WARNING_MSG("(~ts) Failed to secure c2s connection: ~ts",
 		 [xmpp_socket:pp(Socket), format_reason(State, Reason)]),
     State;
 process_terminated(State, _Reason) ->
@@ -431,12 +431,12 @@ bind(R, #{user := U, server := S, access := Access, lang := Lang,
 						 sid => ejabberd_sm:make_sid()}),
 		    State2 = ejabberd_hooks:run_fold(
 			       c2s_session_opened, LServer, State1, []),
-		    ?INFO_MSG("(~s) Opened c2s session for ~s",
+		    ?INFO_MSG("(~ts) Opened c2s session for ~ts",
 			      [xmpp_socket:pp(Socket), jid:encode(JID)]),
 		    {ok, State2};
 		deny ->
 		    ejabberd_hooks:run(forbidden_session_hook, LServer, [JID]),
-		    ?WARNING_MSG("(~s) Forbidden c2s session for ~s",
+		    ?WARNING_MSG("(~ts) Forbidden c2s session for ~ts",
 				 [xmpp_socket:pp(Socket), jid:encode(JID)]),
 		    Txt = ?T("Access denied by service policy"),
 		    {error, xmpp:err_not_allowed(Txt, Lang), State}
@@ -894,7 +894,7 @@ bounce_message_queue({_, Pid} = SID, JID) ->
     SIDs = ejabberd_sm:get_session_sids(U, S, R),
     case lists:member(SID, SIDs) of
 	true ->
-	    ?WARNING_MSG("The session for ~s@~s/~s is supposed to "
+	    ?WARNING_MSG("The session for ~ts@~ts/~ts is supposed to "
 			 "be unregistered, but session identifier ~p "
 			 "still presents in the 'session' table",
 			 [U, S, R, Pid]);
