@@ -337,14 +337,14 @@ gen_calls(#ejabberd_commands{args_example=Values, args=ArgsDesc,
     end.
 
 format_type({list, {_, {tuple, Els}}}) ->
-    io_lib:format("[~s]", [format_type({tuple, Els})]);
+    io_lib:format("[~ts]", [format_type({tuple, Els})]);
 format_type({list, El}) ->
-    io_lib:format("[~s]", [format_type(El)]);
+    io_lib:format("[~ts]", [format_type(El)]);
 format_type({tuple, Els}) ->
     Args = [format_type(El) || El <- Els],
-    io_lib:format("{~s}", [string:join(Args, ", ")]);
+    io_lib:format("{~ts}", [string:join(Args, ", ")]);
 format_type({Name, Type}) ->
-    io_lib:format("~s::~s", [Name, format_type(Type)]);
+    io_lib:format("~ts::~ts", [Name, format_type(Type)]);
 format_type(binary) ->
     "string";
 format_type(atom) ->
@@ -437,7 +437,7 @@ generate_html_output(File, RegExp, Languages) ->
     Langs = binary:split(Languages, <<",">>, [global]),
     Out = lists:map(fun(C) -> gen_doc(C, true, Langs) end, Cmds4),
     {ok, Fh} = file:open(File, [write]),
-    io:format(Fh, "~s", [[html_pre(), Out, html_post()]]),
+    io:format(Fh, "~ts", [[html_pre(), Out, html_post()]]),
     file:close(Fh),
     ok.
 
@@ -463,7 +463,7 @@ generate_md_output(File, RegExp, Languages) ->
 	    "// Autogenerated with 'ejabberdctl gen_markdown_doc_for_commands'\n---">>,
     Out = lists:map(fun(C) -> gen_doc(C, false, Langs) end, Cmds4),
     {ok, Fh} = file:open(File, [write]),
-    io:format(Fh, "~s~s", [Header, Out]),
+    io:format(Fh, "~ts~ts", [Header, Out]),
     file:close(Fh),
     ok.
 
