@@ -40,15 +40,12 @@
 
 -include("ejabberd_http.hrl").
 
--define(PING_INTERVAL, 60).
--define(WEBSOCKET_TIMEOUT, 300).
-
 -record(state,
         {socket                       :: ws_socket(),
-         ping_interval = ?PING_INTERVAL :: non_neg_integer(),
+         ping_interval                :: non_neg_integer(),
          ping_timer = make_ref()      :: reference(),
          pong_expected = false        :: boolean(),
-         timeout = ?WEBSOCKET_TIMEOUT :: non_neg_integer(),
+         timeout                      :: non_neg_integer(),
          timer = make_ref()           :: reference(),
          input = []                   :: list(),
 	 active = false               :: boolean(),
@@ -107,9 +104,8 @@ close({http_ws, FsmRef, _IP}) ->
 reset_stream({http_ws, _FsmRef, _IP} = Socket) ->
     Socket.
 
-change_shaper({http_ws, _FsmRef, _IP}, _Shaper) ->
-    %% TODO???
-    ok.
+change_shaper({http_ws, FsmRef, _IP}, Shaper) ->
+    p1_fsm:send_all_state_event(FsmRef, {new_shaper, Shaper}).
 
 get_transport(_Socket) ->
     websocket.
@@ -133,12 +129,8 @@ init([{#ws{ip = IP, http_opts = HOpts}, _} = WS]) ->
                                (_) -> false
                             end, HOpts),
     Opts = ejabberd_c2s_config:get_c2s_limits() ++ SOpts,
-    PingInterval = ejabberd_config:get_option(
-                     {websocket_ping_interval, ejabberd_config:get_myname()},
-                     ?PING_INTERVAL) * 1000,
-    WSTimeout = ejabberd_config:get_option(
-                  {websocket_timeout, ejabberd_config:get_myname()},
-                  ?WEBSOCKET_TIMEOUT) * 1000,
+    PingInterval = ejabberd_option:websocket_ping_interval(),
+    WSTimeout = ejabberd_option:websocket_timeout(),
     Socket = {http_ws, self(), IP},
     ?DEBUG("Client connected through websocket ~p",
 	   [Socket]),
@@ -168,7 +160,10 @@ handle_event({activate, From}, StateName, State) ->
 		       end, Input),
 		     State#state{active = false, input = []}
 	     end,
-    {next_state, StateName, State1#state{c2s_pid = From}}.
+    {next_state, StateName, State1#state{c2s_pid = From}};
+handle_event({new_shaper, Shaper}, StateName, #state{ws = {_, WsPid}} = StateData) ->
+    WsPid ! {new_shaper, Shaper},
+    {next_state, StateName, StateData}.
 
 handle_sync_event({send_xml, Packet}, _From, StateName,
 		  #state{ws = {_, WsPid}, rfc_compilant = R} = StateData) ->
@@ -201,15 +196,15 @@ handle_sync_event({send_xml, Packet}, _From, StateName,
     case Packet2 of
         {xmlstreamstart, Name, Attrs3} ->
             B = fxml:element_to_binary(#xmlel{name = Name, attrs = Attrs3}),
-            WsPid ! {text, <<(binary:part(B, 0, byte_size(B)-2))/binary, ">">>};
+            route_text(WsPid, <<(binary:part(B, 0, byte_size(B)-2))/binary, ">">>);
         {xmlstreamend, Name} ->
-            WsPid ! {text, <<"</", Name/binary, ">">>};
+            route_text(WsPid, <<"</", Name/binary, ">">>);
         {xmlstreamelement, El} ->
-            WsPid ! {text, fxml:element_to_binary(El)};
+            route_text(WsPid, fxml:element_to_binary(El));
         {xmlstreamraw, Bin} ->
-            WsPid ! {text, Bin};
+            route_text(WsPid, Bin);
         {xmlstreamcdata, Bin2} ->
-            WsPid ! {text, Bin2};
+            route_text(WsPid, Bin2);
         skip ->
             ok
     end,
@@ -224,7 +219,7 @@ handle_sync_event(close, _From, StateName, #state{ws = {_, WsPid}, rfc_compilant
   when StateName /= stream_end_sent ->
     Close = #xmlel{name = <<"close">>,
                    attrs = [{<<"xmlns">>, <<"urn:ietf:params:xml:ns:xmpp-framing">>}]},
-    WsPid ! {text, fxml:element_to_binary(Close)},
+    route_text(WsPid, fxml:element_to_binary(Close)),
     {stop, normal, StateData};
 handle_sync_event(close, _From, _StateName, StateData) ->
     {stop, normal, StateData}.
@@ -366,3 +361,8 @@ parsed_items(List) ->
     after 0 ->
             lists:reverse(List)
     end.
+
+-spec route_text(pid(), binary()) -> ok.
+route_text(Pid, Data) ->
+    Pid ! {text, Data},
+    ok.
