@@ -523,7 +523,7 @@ transform_globals(Opts) ->
 transform_globals(Opt, Opts) when Opt == override_global;
 				  Opt == override_local;
 				  Opt == override_acls ->
-    ?WARNING_MSG("Option '~s' has no effect anymore", [Opt]),
+    ?WARNING_MSG("Option '~ts' has no effect anymore", [Opt]),
     Opts;
 transform_globals({node_start, _}, Opts) ->
     ?WARNING_MSG("Option 'node_start' has no effect anymore", []),
