@@ -40,7 +40,9 @@ opt_type(acl) ->
 opt_type(acme) ->
     econf:options(
       #{ca_url => econf:url(),
-	contact => econf:binary("^[a-zA-Z]+:[^:]+$")},
+	contact => econf:list_or_single(econf:binary("^[a-zA-Z]+:[^:]+$")),
+	auto => econf:bool(),
+	cert_type => econf:enum([ec, rsa])},
       [unique, {return, map}]);
 opt_type(allow_contrib_modules) ->
     econf:bool();
@@ -409,7 +411,9 @@ opt_type(jwt_key) ->
                   {error, Reason} ->
                       econf:fail({read_file, Reason, Path})
               end
-      end).
+      end);
+opt_type(jwt_auth_only_rule) ->
+    econf:atom().
 
 %% We only define the types of options that cannot be derived
 %% automatically by tools/opt_type.sh script
@@ -599,7 +603,7 @@ options() ->
       fun(Host) -> ejabberd_config:default_ram_db(Host, ejabberd_sm) end},
      {sm_use_cache,
       fun(Host) -> ejabberd_config:get_option({use_cache, Host}) end},
-     {sql_type, undefined},
+     {sql_type, odbc},
      {sql_connect_timeout, timer:seconds(5)},
      {sql_database, undefined},
      {sql_keepalive_interval, undefined},
@@ -635,7 +639,8 @@ options() ->
      {websocket_origin, []},
      {websocket_ping_interval, timer:seconds(60)},
      {websocket_timeout, timer:minutes(5)},
-     {jwt_key, undefined}].
+     {jwt_key, undefined},
+     {jwt_auth_only_rule, none}].
 
 -spec globals() -> [atom()].
 globals() ->
@@ -698,6 +703,7 @@ globals() ->
      sm_cache_life_time,
      sm_cache_missed,
      sm_cache_size,
+     trusted_proxies,
      validate_stream,
      version,
      websocket_origin,
