@@ -100,8 +100,12 @@ register_route(Domain, ServerHost, _LocalHint, N, Pid) ->
 
 unregister_route(Domain, undefined, Pid) ->
     F = fun () ->
-		case mnesia:match_object(
-		       #route{domain = Domain, pid = Pid, _ = '_'}) of
+		case mnesia:select(
+		       route,
+		       ets:fun2ms(
+			 fun(#route{domain = D, pid = P} = R)
+			       when D == Domain, P == Pid -> R
+			 end)) of
 		    [R] -> mnesia:delete_object(R);
 		    _ -> ok
 		end
@@ -109,8 +113,12 @@ unregister_route(Domain, undefined, Pid) ->
     transaction(F);
 unregister_route(Domain, _, Pid) ->
     F = fun () ->
-		case mnesia:match_object(
-		       #route{domain = Domain, pid = Pid, _ = '_'}) of
+		case mnesia:select(
+		       route,
+		       ets:fun2ms(
+			 fun(#route{domain = D, pid = P} = R)
+			       when D == Domain, P == Pid -> R
+			 end)) of
 		    [R] ->
 			I = R#route.local_hint,
 			ServerHost = R#route.server_host,
@@ -147,15 +155,18 @@ init([]) ->
     mnesia:subscribe({table, route, simple}),
     lists:foreach(
       fun (Pid) -> erlang:monitor(process, Pid) end,
-      mnesia:dirty_select(route,
-			  [{#route{pid = '$1', _ = '_'}, [], ['$1']}])),
+      mnesia:dirty_select(
+	route,
+	ets:fun2ms(
+	  fun(#route{pid = Pid}) -> Pid end))),
     {ok, #state{}}.
 
-handle_call(_Request, _From, State) ->
-    Reply = ok,
-    {reply, Reply, State}.
+handle_call(Request, From, State) ->
+    ?WARNING_MSG("Unexpected call from ~p: ~p", [From, Request]),
+    {noreply, State}.
 
-handle_cast(_Msg, State) ->
+handle_cast(Msg, State) ->
+    ?WARNING_MSG("Unexpected cast: ~p", [Msg]),
     {noreply, State}.
 
 handle_info({mnesia_table_event,
@@ -166,8 +177,12 @@ handle_info({mnesia_table_event, _}, State) ->
     {noreply, State};
 handle_info({'DOWN', _Ref, _Type, Pid, _Info}, State) ->
     F = fun () ->
-		Es = mnesia:select(route,
-				   [{#route{pid = Pid, _ = '_'}, [], ['$_']}]),
+		Es = mnesia:select(
+		       route,
+		       ets:fun2ms(
+			 fun(#route{pid = P} = E)
+			       when P == Pid -> E
+			 end)),
 		lists:foreach(
 		  fun(E) ->
 			  if is_integer(E#route.local_hint) ->
@@ -187,7 +202,7 @@ handle_info({'DOWN', _Ref, _Type, Pid, _Info}, State) ->
     transaction(F),
     {noreply, State};
 handle_info(Info, State) ->
-    ?ERROR_MSG("unexpected info: ~p", [Info]),
+    ?ERROR_MSG("Unexpected info: ~p", [Info]),
     {noreply, State}.
 
 terminate(_Reason, _State) ->
