@@ -164,8 +164,8 @@ get_password_fun(#{remote_server := RemoteServer,
 		{ok, Password} ->
 		    {Password, undefined};
 		error ->
-		    ?WARNING_MSG("(~s) Domain ~s is unconfigured for "
-				 "external component from ~s",
+		    ?WARNING_MSG("(~ts) Domain ~ts is unconfigured for "
+				 "external component from ~ts",
 				 [xmpp_socket:pp(Socket), RemoteServer,
 				  ejabberd_config:may_hide_data(misc:ip_to_list(IP))]),
 		    {false, undefined}
@@ -176,8 +176,8 @@ handle_auth_success(_, Mech, _,
 		    #{remote_server := RemoteServer, host_opts := HostOpts,
 		      socket := Socket, ip := IP,
 		      global_routes := GlobalRoutes} = State) ->
-    ?INFO_MSG("(~s) Accepted external component ~s authentication "
-	      "for ~s from ~s",
+    ?INFO_MSG("(~ts) Accepted external component ~ts authentication "
+	      "for ~ts from ~ts",
 	      [xmpp_socket:pp(Socket), Mech, RemoteServer,
 	       ejabberd_config:may_hide_data(misc:ip_to_list(IP))]),
     Routes = if GlobalRoutes ->
@@ -195,8 +195,8 @@ handle_auth_success(_, Mech, _,
 handle_auth_failure(_, Mech, Reason,
 		    #{remote_server := RemoteServer,
 		      socket := Socket, ip := IP} = State) ->
-    ?WARNING_MSG("(~s) Failed external component ~s authentication "
-		 "for ~s from ~s: ~s",
+    ?WARNING_MSG("(~ts) Failed external component ~ts authentication "
+		 "for ~ts from ~ts: ~ts",
 		 [xmpp_socket:pp(Socket), Mech, RemoteServer,
 		  ejabberd_config:may_hide_data(misc:ip_to_list(IP)),
 		  Reason]),
@@ -272,7 +272,7 @@ listen_opt_type(shaper_rule) ->
     econf:and_then(
       econf:shaper(),
       fun(S) ->
-	      ?WARNING_MSG("Listening option 'shaper_rule' of module ~s "
+	      ?WARNING_MSG("Listening option 'shaper_rule' of module ~ts "
 			   "is renamed to 'shaper'. Please adjust your "
 			   "configuration", [?MODULE]),
 	      S
