@@ -46,12 +46,11 @@ init([]) ->
 	   worker(ejabberd_admin),
 	   supervisor(ejabberd_listener),
 	   worker(ejabberd_pkix),
-	   worker(ejabberd_acme),
 	   worker(acl),
 	   worker(ejabberd_shaper),
 	   supervisor(ejabberd_db_sup),
 	   supervisor(ejabberd_backend_sup),
-	   supervisor(ejabberd_rdbms),
+	   supervisor(ejabberd_sql_sup),
 	   worker(ejabberd_iq),
 	   worker(ejabberd_router),
 	   worker(ejabberd_router_multicast),
@@ -64,6 +63,7 @@ init([]) ->
 	   worker(ejabberd_captcha),
 	   worker(ext_mod),
 	   supervisor(ejabberd_gen_mod_sup, gen_mod),
+	   worker(ejabberd_acme),
 	   worker(ejabberd_auth),
 	   worker(ejabberd_oauth)]}}.
 
