@@ -94,7 +94,7 @@ handle_event({set_alarm, {process_memory_high_watermark, Pid}}, State) ->
     case proc_stat(Pid, get_app_pids()) of
 	#proc_stat{name = Name} = ProcStat ->
 	    error_logger:warning_msg(
-	      "Process ~p consumes more than 5% of OS memory (~s)~n",
+	      "Process ~p consumes more than 5% of OS memory (~ts)~n",
 	      [Name, format_proc(ProcStat)]),
 	    handle_overload(State),
 	    {ok, State};
@@ -140,8 +140,8 @@ handle_overload(_State, Procs) ->
 	    error_logger:warning_msg(
 	      "The system is overloaded with ~b messages "
 	      "queued by ~b process(es) (~b%) "
-	      "from the following applications: ~s; "
-	      "the top processes are:~n~s~n",
+	      "from the following applications: ~ts; "
+	      "the top processes are:~n~ts~n",
 	      [TotalMsgs, ProcsNum,
 	       round(ProcsNum*100/length(Procs)),
 	       format_apps(Apps),
@@ -246,13 +246,13 @@ format_proc(#proc_stat{qlen = Len, memory = Mem, initial_call = InitCall,
 		       current_function = CurrFun, ancestors = Ancs,
 		       application = App}) ->
     io_lib:format(
-      "msgs = ~b, memory = ~b, initial_call = ~s, "
-      "current_function = ~s, ancestors = ~w, application = ~w",
+      "msgs = ~b, memory = ~b, initial_call = ~ts, "
+      "current_function = ~ts, ancestors = ~w, application = ~w",
       [Len, Mem, format_mfa(InitCall), format_mfa(CurrFun), Ancs, App]).
 
 -spec format_mfa(mfa()) -> iodata().
 format_mfa({M, F, A}) when is_atom(M), is_atom(F), is_integer(A) ->
-    io_lib:format("~s:~s/~b", [M, F, A]);
+    io_lib:format("~ts:~ts/~b", [M, F, A]);
 format_mfa(WTF) ->
     io_lib:format("~w", [WTF]).
 
