@@ -150,30 +150,6 @@ url_to_path(URL) -> str:tokens(URL, <<"/">>).
 %%%==================================
 %%%% process/2
 
-process([<<"doc">>, LocalFile], _Request) ->
-    DocPath = case os:getenv("EJABBERD_DOC_PATH") of
-		P when is_list(P) -> P;
-		false -> <<"/share/doc/ejabberd/">>
-	      end,
-    FileName = filename:join(DocPath, LocalFile),
-    case file:read_file(FileName) of
-      {ok, FileContents} ->
-	  ?DEBUG("Delivering content.", []),
-	  {200, [{<<"Server">>, <<"ejabberd">>}], FileContents};
-      {error, Error} ->
-	  Help = <<" ", FileName/binary,
-		   " - Try to specify the path to ejabberd "
-		   "documentation with the environment variable "
-		   "EJABBERD_DOC_PATH. Check the ejabberd "
-		   "Guide for more information.">>,
-	  ?WARNING_MSG("Problem '~p' accessing the local Guide file ~s", [Error, Help]),
-	  case Error of
-	    eacces -> {403, [], <<"Forbidden", Help/binary>>};
-	    enoent -> {307, [{<<"Location">>, <<"http://docs.ejabberd.im/admin/guide/configuration/">>}], <<"Not found", Help/binary>>};
-	    _Else ->
-		{404, [], <<(iolist_to_binary(atom_to_list(Error)))/binary, Help/binary>>}
-	  end
-    end;
 process([<<"server">>, SHost | RPath] = Path,
 	#request{auth = Auth, lang = Lang, host = HostHTTP,
 		 method = Method} =
@@ -214,30 +190,30 @@ process(RPath,
 		 method = Method} =
 	    Request) ->
     case get_auth_admin(Auth, HostHTTP, RPath, Method) of
-      {ok, {User, Server}} ->
-	  AJID = get_jid(Auth, HostHTTP, Method),
-	  process_admin(global,
-			Request#request{path = RPath,
-					us = {User, Server}},
-			AJID);
-      {unauthorized, <<"no-auth-provided">>} ->
-	  {401,
-	   [{<<"WWW-Authenticate">>,
-	     <<"basic realm=\"ejabberd\"">>}],
-	   ejabberd_web:make_xhtml([?XCT(<<"h1">>,
-					 ?T("Unauthorized"))])};
-      {unauthorized, Error} ->
-	  {BadUser, _BadPass} = Auth,
-	  {IPT, _Port} = Request#request.ip,
-	  IPS = ejabberd_config:may_hide_data(misc:ip_to_list(IPT)),
-	  ?WARNING_MSG("Access of ~p from ~p failed with error: ~p",
-		       [BadUser, IPS, Error]),
-	  {401,
-	   [{<<"WWW-Authenticate">>,
-	     <<"basic realm=\"auth error, retry login "
-	       "to ejabberd\"">>}],
-	   ejabberd_web:make_xhtml([?XCT(<<"h1">>,
-					 ?T("Unauthorized"))])}
+	{ok, {User, Server}} ->
+	    AJID = get_jid(Auth, HostHTTP, Method),
+	    process_admin(global,
+			  Request#request{path = RPath,
+					  us = {User, Server}},
+			  AJID);
+	{unauthorized, <<"no-auth-provided">>} ->
+	    {401,
+	     [{<<"WWW-Authenticate">>,
+	       <<"basic realm=\"ejabberd\"">>}],
+	     ejabberd_web:make_xhtml([?XCT(<<"h1">>,
+					   ?T("Unauthorized"))])};
+	{unauthorized, Error} ->
+	    {BadUser, _BadPass} = Auth,
+	    {IPT, _Port} = Request#request.ip,
+	    IPS = ejabberd_config:may_hide_data(misc:ip_to_list(IPT)),
+	    ?WARNING_MSG("Access of ~p from ~p failed with error: ~p",
+			 [BadUser, IPS, Error]),
+	    {401,
+	     [{<<"WWW-Authenticate">>,
+	       <<"basic realm=\"auth error, retry login "
+		 "to ejabberd\"">>}],
+	     ejabberd_web:make_xhtml([?XCT(<<"h1">>,
+					   ?T("Unauthorized"))])}
     end.
 
 get_auth_admin(Auth, HostHTTP, RPath, Method) ->
@@ -246,8 +222,13 @@ get_auth_admin(Auth, HostHTTP, RPath, Method) ->
 	  {HostOfRule, AccessRule} = get_acl_rule(RPath, Method),
 	    try jid:decode(SJID) of
 		#jid{user = <<"">>, server = User} ->
-		    get_auth_account(HostOfRule, AccessRule, User, HostHTTP,
-				     Pass);
+		    case ejabberd_router:is_my_host(HostHTTP) of
+			true ->
+			    get_auth_account(HostOfRule, AccessRule, User, HostHTTP,
+					     Pass);
+			_ ->
+			    {unauthorized, <<"missing-server">>}
+		    end;
 		#jid{user = User, server = Server} ->
 		    get_auth_account(HostOfRule, AccessRule, User, Server,
 				     Pass)
@@ -260,6 +241,13 @@ get_auth_admin(Auth, HostHTTP, RPath, Method) ->
 
 get_auth_account(HostOfRule, AccessRule, User, Server,
 		 Pass) ->
+    case lists:member(Server, ejabberd_config:get_option(hosts)) of
+	true -> get_auth_account2(HostOfRule, AccessRule, User, Server, Pass);
+	false -> {unauthorized, <<"inexistent-host">>}
+    end.
+
+get_auth_account2(HostOfRule, AccessRule, User, Server,
+		 Pass) ->
     case ejabberd_auth:check_password(User, <<"">>, Server, Pass) of
       true ->
 	  case any_rules_allowed(HostOfRule, AccessRule,
@@ -438,7 +426,7 @@ process_admin(_Host, #request{path = [<<"additions.js">>]}, _) ->
 process_admin(global, #request{path = [<<"vhosts">>], lang = Lang}, AJID) ->
     Res = list_vhosts(Lang, AJID),
     make_xhtml((?H1GL((translate:translate(Lang, ?T("Virtual Hosts"))),
-		      <<"virtualhosting">>, ?T("Virtual Hosting")))
+		      <<"virtual-hosting">>, ?T("Virtual Hosting")))
 		 ++ Res,
 	       global, Lang, AJID);
 process_admin(Host,  #request{path = [<<"users">>], q = Query,
@@ -473,8 +461,8 @@ process_admin(Host, #request{path = [<<"last-activity">>],
 		list_last_activity(Host, Lang, false, Month);
 	    _ -> list_last_activity(Host, Lang, true, Month)
 	  end,
-    make_xhtml([?XCT(<<"h1">>, ?T("Users Last Activity"))]
-		 ++
+    PageH1 = ?H1GL(translate:translate(Lang, ?T("Users Last Activity")), <<"mod-last">>, <<"mod_last">>),
+    make_xhtml(PageH1 ++
 		 [?XAE(<<"form">>,
 		       [{<<"action">>, <<"">>}, {<<"method">>, <<"post">>}],
 		       [?CT(?T("Period: ")),
@@ -504,8 +492,8 @@ process_admin(Host, #request{path = [<<"last-activity">>],
 	       Host, Lang, AJID);
 process_admin(Host, #request{path = [<<"stats">>], lang = Lang}, AJID) ->
     Res = get_stats(Host, Lang),
-    make_xhtml([?XCT(<<"h1">>, ?T("Statistics"))] ++ Res,
-	       Host, Lang, AJID);
+    PageH1 = ?H1GL(translate:translate(Lang, ?T("Statistics")), <<"mod-stats">>, <<"mod_stats">>),
+    make_xhtml(PageH1 ++ Res, Host, Lang, AJID);
 process_admin(Host, #request{path = [<<"user">>, U],
 			     q = Query, lang = Lang}, AJID) ->
     case ejabberd_auth:user_exists(U, Host) of
@@ -915,7 +903,7 @@ user_info(User, Server, Query, Lang) ->
 			 end;
 		     _ -> translate:translate(Lang, ?T("Online"))
 		   end,
-    [?XC(<<"h1">>, (str:format(translate:translate(Lang, ?T("User ~s")),
+    [?XC(<<"h1">>, (str:format(translate:translate(Lang, ?T("User ~ts")),
                                                 [us_to_list(US)])))]
       ++
       case Res of
@@ -1280,9 +1268,7 @@ get_node(global, Node, [<<"backup">>], Query, Lang) ->
 				   [?CT(?T("Export data of users in a host to PIEFXIS "
 					   "files (XEP-0227):")),
 				    ?C(<<" ">>),
-				    ?INPUT(<<"text">>,
-					   <<"export_piefxis_host_dirhost">>,
-					   (ejabberd_config:get_myname()))]),
+				    make_select_host(Lang, <<"export_piefxis_host_dirhost">>)]),
 			       ?XE(<<"td">>,
 				   [?INPUT(<<"text">>,
 					   <<"export_piefxis_host_dirpath">>,
@@ -1296,9 +1282,7 @@ get_node(global, Node, [<<"backup">>], Query, Lang) ->
                                    [?CT(?T("Export all tables as SQL queries "
 					   "to a file:")),
                                     ?C(<<" ">>),
-                                    ?INPUT(<<"text">>,
-                                           <<"export_sql_filehost">>,
-                                           (ejabberd_config:get_myname()))]),
+                                    make_select_host(Lang, <<"export_sql_filehost">>)]),
                                ?XE(<<"td">>,
 				   [?INPUT(<<"text">>,
                                            <<"export_sql_filepath">>,
@@ -1468,6 +1452,15 @@ node_parse_query(Node, Query) ->
 	  end
     end.
 
+make_select_host(Lang, Name) ->
+    ?XAE(<<"select">>,
+	 [{<<"name">>, Name}],
+	 (lists:map(fun (Host) ->
+			    ?XACT(<<"option">>,
+				  ([{<<"value">>, Host}]), Host)
+		    end,
+		    ejabberd_config:get_option(hosts)))).
+
 db_storage_select(ID, Opt, Lang) ->
     ?XAE(<<"select">>,
 	 [{<<"name">>, <<"table", ID/binary>>}],
