@@ -22,9 +22,10 @@
 %%% 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 %%%
 %%%-------------------------------------------------------------------
-
 -module(elixir_logger_backend).
 
+-ifdef(ELIXIR_ENABLED).
+
 -behaviour(gen_event).
 
 -export([init/1, handle_call/2, handle_event/2, handle_info/2, terminate/2,
@@ -57,7 +58,7 @@ handle_event({log, LagerMsg}, State) ->
             notify(Mode, {MsgLevel, GroupLeader, {'Elixir.Logger', Message, Timestamp, Metadata}}),
             {ok, State};
         _ ->
-            {ok, State}            
+            {ok, State}
     end;
 handle_event(_Msg, State) ->
     {ok, State}.
@@ -110,7 +111,7 @@ timestamp(Time, UTCLog) ->
             false -> calendar:now_to_local_time(Time)
         end,
     {Date, {Hours, Minutes, Seconds, Micro div 1000}}.
-    
+
 
 severity_to_level(debug) -> debug;
 severity_to_level(info) -> info;
@@ -120,3 +121,5 @@ severity_to_level(error) -> error;
 severity_to_level(critical) -> error;
 severity_to_level(alert) -> error;
 severity_to_level(emergency) -> error.
+
+-endif.
