@@ -1504,13 +1504,13 @@ send_stanza(FromString, ToString, Stanza) ->
 	Pkt = xmpp:decode(El, ?NS_CLIENT, CodecOpts),
 	ejabberd_router:route(xmpp:set_from_to(Pkt, From, To))
     catch _:{xmpp_codec, Why} ->
-	    io:format("incorrect stanza: ~s~n", [xmpp:format_error(Why)]),
+	    io:format("incorrect stanza: ~ts~n", [xmpp:format_error(Why)]),
 	    {error, Why};
 	  _:{badmatch, {error, Why}} ->
 	    io:format("invalid xml: ~p~n", [Why]),
 	    {error, Why};
 	  _:{bad_jid, S} ->
-	    io:format("malformed JID: ~s~n", [S]),
+	    io:format("malformed JID: ~ts~n", [S]),
 	    {error, "JID malformed"}
     end.
 
@@ -1530,7 +1530,7 @@ send_stanza_c2s(Username, Host, Resource, Stanza) ->
 	    io:format("invalid xml: ~p~n", [Why]),
 	    Err;
 	  _:{xmpp_codec, Why} ->
-	    io:format("incorrect stanza: ~s~n", [xmpp:format_error(Why)]),
+	    io:format("incorrect stanza: ~ts~n", [xmpp:format_error(Why)]),
 	    {error, Why}
     end.
 
