@@ -227,7 +227,7 @@ filter_presence({#presence{meta = #{csi_resend := true}}, _} = Acc) ->
 filter_presence({#presence{to = To, type = Type} = Pres,
 		 #{csi_state := inactive} = C2SState})
   when Type == available; Type == unavailable ->
-    ?DEBUG("Got availability presence stanza for ~s", [jid:encode(To)]),
+    ?DEBUG("Got availability presence stanza for ~ts", [jid:encode(To)]),
     enqueue_stanza(presence, Pres, C2SState);
 filter_presence(Acc) ->
     Acc.
@@ -246,7 +246,7 @@ filter_chat_states({#message{from = From, to = To} = Msg,
 		    %% conversations across clients.
 		    Acc;
 		_ ->
-		?DEBUG("Got standalone chat state notification for ~s",
+		?DEBUG("Got standalone chat state notification for ~ts",
 		       [jid:encode(To)]),
 		    enqueue_stanza(chatstate, Msg, C2SState)
 	    end;
@@ -265,7 +265,7 @@ filter_pep({#message{to = To} = Msg,
 	undefined ->
 	    Acc;
 	Node ->
-	    ?DEBUG("Got PEP notification for ~s", [jid:encode(To)]),
+	    ?DEBUG("Got PEP notification for ~ts", [jid:encode(To)]),
 	    enqueue_stanza({pep, Node}, Msg, C2SState)
     end;
 filter_pep(Acc) ->
@@ -277,7 +277,7 @@ filter_other({Stanza, #{jid := JID} = C2SState} = Acc) when ?is_stanza(Stanza) -
 	#{csi_resend := true} ->
 	    Acc;
 	_ ->
-	    ?DEBUG("Won't add stanza for ~s to CSI queue", [jid:encode(JID)]),
+	    ?DEBUG("Won't add stanza for ~ts to CSI queue", [jid:encode(JID)]),
 	    From = case xmpp:get_from(Stanza) of
 		       undefined -> JID;
 		       F -> F
@@ -328,7 +328,7 @@ dequeue_sender(#jid{luser = U, lserver = S} = Sender,
 	    %% This may happen when the module is (re)loaded in runtime
 	    init_csi_state(C2SState);
 	Q ->
-	    ?DEBUG("Flushing packets of ~s@~s from CSI queue of ~s",
+	    ?DEBUG("Flushing packets of ~ts@~ts from CSI queue of ~ts",
 		   [U, S, jid:encode(JID)]),
 	    {Elems, Q1} = queue_take(Sender, Q),
 	    C2SState1 = flush_stanzas(C2SState, Elems),
@@ -337,7 +337,7 @@ dequeue_sender(#jid{luser = U, lserver = S} = Sender,
 
 -spec flush_queue(c2s_state()) -> c2s_state().
 flush_queue(#{csi_queue := Q, jid := JID} = C2SState) ->
-    ?DEBUG("Flushing CSI queue of ~s", [jid:encode(JID)]),
+    ?DEBUG("Flushing CSI queue of ~ts", [jid:encode(JID)]),
     C2SState1 = flush_stanzas(C2SState, queue_to_list(Q)),
     C2SState1#{csi_queue => queue_new()}.
 
