@@ -205,7 +205,7 @@ process_iq(#iq{type = get, from = From, to = To, id = ID, lang = Lang} = IQ,
 		       "with this server")),
     URL = mod_register_opt:redirect_url(Server),
     if (URL /= undefined) and not IsRegistered ->
-	    Txt = translate:translate(Lang, ?T("To register, visit ~s")),
+	    Txt = translate:translate(Lang, ?T("To register, visit ~ts")),
 	    Desc = str:format(Txt, [URL]),
 	    xmpp:make_iq_result(
 	      IQ, #register{instructions = Desc,
@@ -283,7 +283,7 @@ try_set_password(User, Server, Password) ->
 try_set_password(User, Server, Password, #iq{lang = Lang, meta = M} = IQ) ->
     case try_set_password(User, Server, Password) of
 	ok ->
-	    ?INFO_MSG("~s has changed password from ~s",
+	    ?INFO_MSG("~ts has changed password from ~ts",
 		      [jid:encode({User, Server, <<"">>}),
 		       ejabberd_config:may_hide_data(
 			 misc:ip_to_list(maps:get(ip, M, {0,0,0,0})))]),
@@ -341,7 +341,7 @@ try_register(User, Server, Password, SourceRaw, Lang) ->
 	ok ->
 	    JID = jid:make(User, Server),
 	    Source = may_remove_resource(SourceRaw),
-	    ?INFO_MSG("The account ~s was registered from IP address ~s",
+	    ?INFO_MSG("The account ~ts was registered from IP address ~ts",
 		      [jid:encode({User, Server, <<"">>}),
 		       ejabberd_config:may_hide_data(ip_to_string(Source))]),
 	    send_welcome_message(JID),
@@ -401,8 +401,8 @@ send_registration_notifications(Mod, UJID, Source) ->
         [] -> ok;
         JIDs when is_list(JIDs) ->
             Body =
-                (str:format("[~s] The account ~s was registered from "
-                                               "IP address ~s on node ~w using ~p.",
+                (str:format("[~ts] The account ~ts was registered from "
+                                               "IP address ~ts on node ~w using ~p.",
                                                [get_time_string(),
                                                 jid:encode(UJID),
 						ejabberd_config:may_hide_data(
