@@ -67,7 +67,7 @@ log_user_receive({Packet, C2SState}) ->
 
 -spec log_packet(stanza(), binary()) -> ok.
 log_packet(Packet, Host) ->
-    Loggers = gen_mod:get_module_opt(Host, ?MODULE, loggers),
+    Loggers = mod_service_log_opt:loggers(Host),
     ForwardedMsg = #message{from = jid:make(Host),
 			    id = p1_rand:get_string(),
 			    sub_els = [#forwarded{
@@ -78,14 +78,7 @@ log_packet(Packet, Host) ->
       end, Loggers).
 
 mod_opt_type(loggers) ->
-    fun (L) ->
-	    lists:map(fun (S) ->
-			      B = iolist_to_binary(S),
-			      N = jid:nameprep(B),
-			      if N /= error -> N end
-		      end,
-		      L)
-    end.
+    econf:list(econf:domain()).
 
 mod_options(_) ->
     [{loggers, []}].
