@@ -36,12 +36,13 @@
 
 -include("logger.hrl").
 -include("xmpp.hrl").
+-include("translate.hrl").
 
 start(Host, _Opts) ->
     gen_iq_handler:add_iq_handler(ejabberd_local, Host, ?NS_SIC_0,
 				  ?MODULE, process_local_iq),
     gen_iq_handler:add_iq_handler(ejabberd_sm, Host, ?NS_SIC_0,
-				  ?MODULE, process_sm_iq),    
+				  ?MODULE, process_sm_iq),
     gen_iq_handler:add_iq_handler(ejabberd_local, Host, ?NS_SIC_1,
 				  ?MODULE, process_local_iq),
     gen_iq_handler:add_iq_handler(ejabberd_sm, Host, ?NS_SIC_1,
@@ -64,7 +65,7 @@ process_local_iq(#iq{from = #jid{user = User, server = Server,
 		     type = get} = IQ) ->
     get_ip({User, Server, Resource}, IQ);
 process_local_iq(#iq{type = set, lang = Lang} = IQ) ->
-    Txt = <<"Value 'set' of 'type' attribute is not allowed">>,
+    Txt = ?T("Value 'set' of 'type' attribute is not allowed"),
     xmpp:make_error(IQ, xmpp:err_not_allowed(Txt, Lang)).
 
 process_sm_iq(#iq{from = #jid{user = User, server = Server,
@@ -73,10 +74,10 @@ process_sm_iq(#iq{from = #jid{user = User, server = Server,
 		  type = get} = IQ) ->
     get_ip({User, Server, Resource}, IQ);
 process_sm_iq(#iq{type = get, lang = Lang} = IQ) ->
-    Txt = <<"Query to another users is forbidden">>,
+    Txt = ?T("Query to another users is forbidden"),
     xmpp:make_error(IQ, xmpp:err_forbidden(Txt, Lang));
 process_sm_iq(#iq{type = set, lang = Lang} = IQ) ->
-    Txt = <<"Value 'set' of 'type' attribute is not allowed">>,
+    Txt = ?T("Value 'set' of 'type' attribute is not allowed"),
     xmpp:make_error(IQ, xmpp:err_not_allowed(Txt, Lang)).
 
 get_ip({User, Server, Resource},
@@ -89,7 +90,7 @@ get_ip({User, Server, Resource},
 		     end,
 	    xmpp:make_iq_result(IQ, Result);
 	_ ->
-	    Txt = <<"User session not found">>,
+	    Txt = ?T("User session not found"),
 	    xmpp:make_error(IQ, xmpp:err_item_not_found(Txt, Lang))
     end.
 
