@@ -35,8 +35,8 @@
 	 mod_opt_type/1, mod_options/1, depends/2]).
 
 -include("logger.hrl").
-
 -include("xmpp.hrl").
+-include("translate.hrl").
 
 start(Host, _Opts) ->
     gen_iq_handler:add_iq_handler(ejabberd_local, Host,
@@ -50,16 +50,16 @@ reload(_Host, _NewOpts, _OldOpts) ->
     ok.
 
 process_local_iq(#iq{type = set, lang = Lang} = IQ) ->
-    Txt = <<"Value 'set' of 'type' attribute is not allowed">>,
+    Txt = ?T("Value 'set' of 'type' attribute is not allowed"),
     xmpp:make_error(IQ, xmpp:err_not_allowed(Txt, Lang));
 process_local_iq(#iq{type = get, to = To} = IQ) ->
     Host = To#jid.lserver,
-    OS = case gen_mod:get_module_opt(Host, ?MODULE, show_os) of
+    OS = case mod_version_opt:show_os(Host) of
 	     true -> get_os();
 	     false -> undefined
 	 end,
     xmpp:make_iq_result(IQ, #version{name = <<"ejabberd">>,
-				     ver = ejabberd_config:get_version(),
+				     ver = ejabberd_option:version(),
 				     os = OS}).
 
 get_os() ->
@@ -77,7 +77,7 @@ depends(_Host, _Opts) ->
     [].
 
 mod_opt_type(show_os) ->
-    fun (B) when is_boolean(B) -> B end.
+    econf:bool().
 
 mod_options(_Host) ->
     [{show_os, true}].
