@@ -33,11 +33,11 @@
 -behaviour(gen_pubsub_node).
 -author('christophe.romain@process-one.net').
 
--compile([{parse_transform, ejabberd_sql_pt}]).
 
 -include("pubsub.hrl").
 -include("xmpp.hrl").
 -include("ejabberd_sql_pt.hrl").
+-include("translate.hrl").
 
 -export([init/3, terminate/2, options/0, features/0,
     create_node_permission/6, create_node/2, delete_node/1,
@@ -51,7 +51,8 @@
     set_state/1, get_items/7, get_items/3, get_item/7,
     get_item/2, set_item/1, get_item_name/3, node_to_path/1,
     path_to_node/1,
-    get_entity_subscriptions_for_send_last/2, get_last_items/3]).
+    get_entity_subscriptions_for_send_last/2, get_last_items/3,
+    get_only_item/2]).
 
 -export([decode_jid/1, encode_jid/1, encode_jid_like/1,
          decode_affiliation/1, decode_subscriptions/1,
@@ -377,8 +378,8 @@ set_affiliation(Nidx, Owner, Affiliation) ->
     GenKey = jid:remove_resource(SubKey),
     {_, Subscriptions} = select_affiliation_subscriptions(Nidx, GenKey),
     case {Affiliation, Subscriptions} of
-	{none, []} -> del_state(Nidx, GenKey);
-	_ -> update_affiliation(Nidx, GenKey, Affiliation)
+	{none, []} -> {result, del_state(Nidx, GenKey)};
+	_ -> {result, update_affiliation(Nidx, GenKey, Affiliation)}
     end.
 
 get_entity_subscriptions(Host, Owner) ->
@@ -522,7 +523,7 @@ set_subscriptions(Nidx, Owner, Subscription, SubId) ->
 
 replace_subscription(NewSub, SubState) ->
     NewSubs = replace_subscription(NewSub, SubState#pubsub_state.subscriptions, []),
-    set_state(SubState#pubsub_state{subscriptions = NewSubs}).
+    {result, set_state(SubState#pubsub_state{subscriptions = NewSubs})}.
 
 replace_subscription(_, [], Acc) -> Acc;
 replace_subscription({Sub, SubId}, [{_, SubId} | T], Acc) ->
@@ -533,7 +534,7 @@ new_subscription(_Nidx, _Owner, Subscription, SubState) ->
     SubId = pubsub_subscription_sql:make_subid(),
     Subscriptions = [{Subscription, SubId} | SubState#pubsub_state.subscriptions],
     set_state(SubState#pubsub_state{subscriptions = Subscriptions}),
-    {Subscription, SubId}.
+    {result, {Subscription, SubId}}.
 
 unsub_with_subid(Nidx, SubId, SubState) ->
     %%pubsub_subscription_sql:unsubscribe_node(SubState#pubsub_state.stateid, Nidx, SubId),
@@ -541,46 +542,31 @@ unsub_with_subid(Nidx, SubId, SubState) ->
 	    || {S, Sid} <- SubState#pubsub_state.subscriptions,
 		SubId =/= Sid],
     case {NewSubs, SubState#pubsub_state.affiliation} of
-	{[], none} -> del_state(Nidx, element(1, SubState#pubsub_state.stateid));
-	_ -> set_state(SubState#pubsub_state{subscriptions = NewSubs})
+	{[], none} -> {result, del_state(Nidx, element(1, SubState#pubsub_state.stateid))};
+	_ -> {result, set_state(SubState#pubsub_state{subscriptions = NewSubs})}
     end.
 
 get_pending_nodes(Host, Owner) ->
-    GenKey = jid:remove_resource(jid:tolower(Owner)),
-    States = mnesia:match_object(#pubsub_state{stateid = {GenKey, '_'},
-		affiliation = owner, _ = '_'}),
-    Nidxxs = [Nidx || #pubsub_state{stateid = {_, Nidx}} <- States],
+    GenKey = encode_jid(jid:remove_resource(jid:tolower(Owner))),
+    PendingIdxs = case ejabberd_sql:sql_query_t(
+                         ?SQL("select @(nodeid)d from pubsub_state "
+                              "where subscriptions like '%p%' and affiliation='o'"
+                              "and jid=%(GenKey)s")) of
+	{selected, RItems} ->
+            [Nidx || {Nidx} <- RItems];
+        _ ->
+            []
+        end,
     NodeTree = mod_pubsub:tree(Host),
-    Reply = mnesia:foldl(fun (#pubsub_state{stateid = {_, Nidx}} = S, Acc) ->
-		    case lists:member(Nidx, Nidxxs) of
-			true ->
-			    case get_nodes_helper(NodeTree, S) of
-				{value, Node} -> [Node | Acc];
-				false -> Acc
-			    end;
-			false ->
-			    Acc
-		    end
-	    end,
-	    [], pubsub_state),
+    Reply = lists:foldl(fun(Nidx, Acc) ->
+                            case NodeTree:get_node(Nidx) of
+                                #pubsub_node{nodeid = {_, Node}} -> [Node | Acc];
+                                _ -> Acc
+                            end
+                        end,
+                        [], PendingIdxs),
     {result, Reply}.
 
-get_nodes_helper(NodeTree, #pubsub_state{stateid = {_, N}, subscriptions = Subs}) ->
-    HasPending = fun
-	({pending, _}) -> true;
-	(pending) -> true;
-	(_) -> false
-    end,
-    case lists:any(HasPending, Subs) of
-	true ->
-	    case NodeTree:get_node(N) of
-		#pubsub_node{nodeid = {_, Node}} -> {value, Node};
-		_ -> false
-	    end;
-	false ->
-	    false
-    end.
-
 get_states(Nidx) ->
     case ejabberd_sql:sql_query_t(
 	   ?SQL("select @(jid)s, @(affiliation)s, @(subscriptions)s "
@@ -756,6 +742,25 @@ get_last_items(Nidx, _From, Limit) ->
 	    {result, []}
     end.
 
+get_only_item(Nidx, _From) ->
+    SNidx = misc:i2l(Nidx),
+    Query = fun(mssql, _) ->
+	ejabberd_sql:sql_query_t(
+	    [<<"select  itemid, publisher, creation, modification, payload",
+	       " from pubsub_item where nodeid='", SNidx/binary, "'">>]);
+	       (_, _) ->
+		   ejabberd_sql:sql_query_t(
+		       [<<"select itemid, publisher, creation, modification, payload",
+			  " from pubsub_item where nodeid='", SNidx/binary, "'">>])
+	    end,
+    case catch ejabberd_sql:sql_query_t(Query) of
+	{selected, [<<"itemid">>, <<"publisher">>, <<"creation">>,
+		    <<"modification">>, <<"payload">>], RItems} ->
+	    {result, [raw_to_item(Nidx, RItem) || RItem <- RItems]};
+	_ ->
+	    {result, []}
+    end.
+
 get_item(Nidx, ItemId) ->
     case catch ejabberd_sql:sql_query_t(
 		 ?SQL("select @(itemid)s, @(publisher)s, @(creation)s,"
@@ -767,7 +772,7 @@ get_item(Nidx, ItemId) ->
 	{selected, []} ->
 	    {error, xmpp:err_item_not_found()};
 	{'EXIT', _} ->
-	    {error, xmpp:err_internal_server_error(<<"Database failure">>, ejabberd_config:get_mylang())}
+	    {error, xmpp:err_internal_server_error(?T("Database failure"), ejabberd_option:language())}
     end.
 
 get_item(Nidx, ItemId, JID, AccessModel, PresenceSubscription, RosterGroup, _SubId) ->
@@ -840,7 +845,7 @@ del_items(Nidx, ItemIds) ->
 	    I, <<") and nodeid='">>, SNidx, <<"';">>]).
 
 get_item_name(_Host, _Node, Id) ->
-    Id.
+    {result, Id}.
 
 node_to_path(Node) ->
     node_flat:node_to_path(Node).
