@@ -30,18 +30,18 @@
 %%% <p>PubSub node tree plugins are using the {@link gen_nodetree} behaviour.</p>
 %%% <p><strong>The API isn't stabilized yet</strong>. The pubsub plugin
 %%% development is still a work in progress. However, the system is already
-%%% useable and useful as is. Please, send us comments, feedback and
+%%% usable and useful as is. Please, send us comments, feedback and
 %%% improvements.</p>
 
 -module(nodetree_tree_sql).
 -behaviour(gen_pubsub_nodetree).
 -author('christophe.romain@process-one.net').
 
--compile([{parse_transform, ejabberd_sql_pt}]).
 
 -include("pubsub.hrl").
 -include("xmpp.hrl").
 -include("ejabberd_sql_pt.hrl").
+-include("translate.hrl").
 
 -export([init/3, terminate/2, options/0, set_node/1,
     get_node/3, get_node/2, get_node/1, get_nodes/2,
@@ -93,8 +93,8 @@ set_node(Record) when is_record(Record, pubsub_node) ->
     end,
     case Nidx of
 	none ->
-	    Txt = <<"Node index not found">>,
-	    {error, xmpp:err_internal_server_error(Txt, ejabberd_config:get_mylang())};
+	    Txt = ?T("Node index not found"),
+	    {error, xmpp:err_internal_server_error(Txt, ejabberd_option:language())};
 	_ ->
 	    lists:foreach(fun ({Key, Value}) ->
 			SKey = iolist_to_binary(atom_to_list(Key)),
@@ -121,9 +121,9 @@ get_node(Host, Node) ->
 	{selected, [RItem]} ->
 	    raw_to_node(Host, RItem);
 	{'EXIT', _Reason} ->
-	    {error, xmpp:err_internal_server_error(<<"Database failure">>, ejabberd_config:get_mylang())};
+	    {error, xmpp:err_internal_server_error(?T("Database failure"), ejabberd_option:language())};
 	_ ->
-	    {error, xmpp:err_item_not_found(<<"Node not found">>, ejabberd_config:get_mylang())}
+	    {error, xmpp:err_item_not_found(?T("Node not found"), ejabberd_option:language())}
     end.
 
 get_node(Nidx) ->
@@ -135,9 +135,9 @@ get_node(Nidx) ->
 	{selected, [{Host, Node, Parent, Type}]} ->
 	    raw_to_node(Host, {Node, Parent, Type, Nidx});
 	{'EXIT', _Reason} ->
-	    {error, xmpp:err_internal_server_error(<<"Database failure">>, ejabberd_config:get_mylang())};
+	    {error, xmpp:err_internal_server_error(?T("Database failure"), ejabberd_option:language())};
 	_ ->
-	    {error, xmpp:err_item_not_found(<<"Node not found">>, ejabberd_config:get_mylang())}
+	    {error, xmpp:err_item_not_found(?T("Node not found"), ejabberd_option:language())}
     end.
 
 get_nodes(Host, _From) ->
@@ -259,9 +259,9 @@ create_node(Host, Node, Type, Owner, Options, Parents) ->
 		    {error, xmpp:err_forbidden()}
 	    end;
 	{result, _} ->
-	    {error, xmpp:err_conflict(<<"Node already exists">>, ejabberd_config:get_mylang())};
+	    {error, xmpp:err_conflict(?T("Node already exists"), ejabberd_option:language())};
 	{error, db_fail} ->
-	    {error, xmpp:err_internal_server_error(<<"Database failure">>, ejabberd_config:get_mylang())}
+	    {error, xmpp:err_internal_server_error(?T("Database failure"), ejabberd_option:language())}
     end.
 
 delete_node(Host, Node) ->
