@@ -193,7 +193,8 @@ service_disco_items(Config) ->
 service_vcard(Config) ->
     MUC = muc_jid(Config),
     ct:comment("Retreiving vCard from ~s", [jid:encode(MUC)]),
-    #iq{type = result, sub_els = [#vcard_temp{}]} =
+    VCard = mod_muc_opt:vcard(?config(server, Config)),
+    #iq{type = result, sub_els = [VCard]} =
 	send_recv(Config, #iq{type = get, to = MUC, sub_els = [#vcard_temp{}]}),
     disconnect(Config).
 
@@ -783,7 +784,7 @@ change_affiliation_master(Config) ->
 		  #muc_item{affiliation = Aff} ->
 		      ok
 	      end
-      end, [{member, participant, available}, {none, participant, available},
+      end, [{member, participant, available}, {none, visitor, available},
 	    {admin, moderator, available}, {owner, moderator, available},
 	    {outcast, none, unavailable}]),
     ok = leave(Config),
