@@ -40,6 +40,7 @@
 single_cases() ->
     {upload_single, [sequence],
      [single_test(feature_enabled),
+      single_test(service_vcard),
       single_test(get_max_size),
       single_test(slot_request),
       single_test(put_get_request),
@@ -52,6 +53,14 @@ feature_enabled(Config) ->
       end, namespaces()),
     disconnect(Config).
 
+service_vcard(Config) ->
+    Upload = upload_jid(Config),
+    ct:comment("Retreiving vCard from ~s", [jid:encode(Upload)]),
+    VCard = mod_http_upload_opt:vcard(?config(server, Config)),
+    #iq{type = result, sub_els = [VCard]} =
+	send_recv(Config, #iq{type = get, to = Upload, sub_els = [#vcard_temp{}]}),
+    disconnect(Config).
+
 get_max_size(Config) ->
     Xs = get_disco_info_xdata(Config),
     lists:foreach(
